// Avago RGBC Sensor to fischertechnik TX Controller
//
// http://www.fischertechnik.de

// http://sites.google.com/site/vilorei/
// Jan 05, 2011 - With I2C RGB LED with colour identification
// Jan 24, 2011 - Library

#include <Wire.h>
#include <I2C_RGBC_Reader.h>

I2C_RGBC_Reader myRGBC_Reader;

const int out1pin = 2;      
const int out2pin = 3;
const int LEDpin = 13;

void setup() {
  Wire.begin();
  Serial.begin(19200);
  Serial.print("\n\n\n\n***\n");

  myRGBC_Reader.begin();
  myRGBC_Reader.standard();

  pinMode(out1pin, OUTPUT);      
  pinMode(out2pin, OUTPUT);      
  pinMode(LEDpin, OUTPUT);      

  digitalWrite(out1pin, LOW);
  digitalWrite(out2pin, LOW);
  digitalWrite(LEDpin, LOW);

  help();
}

void help() {
  Serial.println();
  Serial.print(myRGBC_Reader.WhoAmI());
  Serial.print("\n---\n");
  Serial.println("v : show settings");          // 0x76
  Serial.println("0..3 : memorise colour - object required");          // 0x76
  Serial.println("SPACE : find memorised colour and send to TX-C - object required");          // 0x76
  Serial.println();
}


int r, g, b, c;
int n, p;
int command = 0;  // This is the command char, in ascii form, sent from the serial port     
String s;

void loop() {

  if (Serial.available()) {  // Look for char in serial que and process if found
    command = Serial.read(); 
    delay(100);

    if (command == 0x20) {  // SPACE
      Serial.println("SPACE : find memorised colour and send to TX-C");

      digitalWrite(LEDpin, HIGH);
      myRGBC_Reader.getRGBC(r, g, b, c);

      Serial.print("rgbc");
      Serial.print("\t");
      Serial.print(r);
      Serial.print("\t");
      Serial.print(g);
      Serial.print("\t");
      Serial.print(b);
      Serial.print("\t");
      Serial.print(c);
      Serial.print("\n");

      myRGBC_Reader.recognise(n, p);    
      Serial.print("#, prox");
      Serial.print("\t");
      Serial.print(n);
      Serial.print("\t");
      Serial.print(p);
      Serial.print("%\t");

      if (n==0) {
        digitalWrite(out1pin, LOW);
        digitalWrite(out2pin, LOW);
      } 
      else if (n==1) {
        digitalWrite(out1pin, LOW);
        digitalWrite(out2pin, HIGH);
      } 
      else if (n==2) {
        digitalWrite(out1pin, HIGH);
        digitalWrite(out2pin, LOW);
      } 
      else if (n==3) {
        digitalWrite(out1pin, HIGH);
        digitalWrite(out2pin, HIGH);
      } 
      else {
        digitalWrite(out1pin, LOW);
        digitalWrite(out2pin, LOW);
      }

      digitalWrite(LEDpin, LOW);
    } 

    else if (command == 0x69) {   
      Serial.println("s standard configuration");
      Serial.println("may take a while...");
      myRGBC_Reader.standard();
    }
    else if ((command >= 0x30) && (command <= 0x37)) {   // learn 1..8 colours
      Serial.println("0..7 learn");

      Serial.print("> colour object required\n");
      while (!Serial.available());
      myRGBC_Reader.memorise((command - 0x30));    
    }
    else if (command == 0x63) {   // 123c 
      Serial.println("c calibrate");
      Serial.print("> white object required\n");

      while (!Serial.available());
      Serial.println("may take a while...");
      myRGBC_Reader.calibrate();    
    }
    else if (command == 0x6F) {   // 4o
      Serial.println("o offset");
      Serial.print("> no object and sensor taped\n");

      while (!Serial.available());
      Serial.println("may take a while...");
      myRGBC_Reader.offset();
    }
    else if (command == 0x77) {   // 5w
      Serial.println("w white");

      Serial.print("> white object required\n");
      while (!Serial.available());
      myRGBC_Reader.white();
    }
    else if (command == 0x76) {   // v
      Serial.println("v parameters");

      myRGBC_Reader.parameters();
    }

    Serial.print("\n---\n");
    help();

    Serial.flush();
    command = 0;
    delay(100);
  }
}









